import 'dart:convert';

import 'package:common_module/config/global_config.dart';
import 'package:flutter/foundation.dart';
import 'package:frog_app_utils_plugin/environment/frog_environment_plugin.dart';
import 'package:frog_app_utils_plugin/frog_app.dart';
import 'package:frog_log_plugin/log_utils.dart';

import 'service.dart';

class StaticUrl {
  String title; //标题
  String url; //链接
  String remark; //标记
  String name; //名称

  StaticUrl(this.title, this.url, this.remark, this.name);

  //拼接链接参数
  String getSplicingUrl(Map<String, String> param) {
    if (param.isEmpty) return url;
    try {
      Uri uri = Uri.parse(url);
      if (uri != null) {
        Map<String, String> queryMap = Map<String, String>();
        if (uri.queryParameters?.isNotEmpty == true) {
          queryMap.addAll(uri.queryParameters);
        }
        queryMap.addAll(param);
        Uri newUri = Uri(
            scheme: uri.scheme,
            userInfo: uri.userInfo,
            host: uri.host,
            port: uri.port,
            pathSegments: uri.pathSegments,
            queryParameters: queryMap,
            fragment: uri.fragment);
        return newUri?.toString();
      }
    } catch (e) {
      L.error(tag: 'static_url_service', message: 'getSplicingUrl error:$e');
    }
    return '';
  }

  /// 链接中含有cmsPages，属于公用的，和平台无关，链接中需要去掉"/fish"
  StaticUrl.fromJson(Map<String, dynamic> json, bool isLocal, {bool isCmsPages = false})
      : title = (json == null || json['title'] == null) ? '' : (isLocal ? json['title'] : utf8.decode(json['title'].toString().codeUnits)),
        url = (json == null || json['url'] == null)
            ? ''
            : GlobalConfig().normalScheme +
                json['url'] +
                (FrogApp.isDebug ? '?debug=1' : '') +
                (FrogApp.isDebug ? (kIsWeb ? "&isweb=1" : '') : (kIsWeb ? "?isweb=1" : '')),
        remark = (json != null) ? (json['remark'] ?? '') : '';

  ///
  // static String getEnv() {
  //   var currentBetaEnv = FrogEnvironmentPlugin().getCurrentBetaEnv();
  //   return currentBetaEnv?.isEmpty == true ? "/prod" : currentBetaEnv;
  // }
}

class StaticUrlConfig {
  StaticUrl logoutAccount;

  StaticUrlConfig(
    this.logoutAccount,
  );

  StaticUrlConfig.fromJson(Map<String, dynamic> json, bool isLocal) : logoutAccount = StaticUrl.fromJson(json['logoutAccount'], isLocal);
}
