import 'dart:convert';

import 'package:common_module/config/global_config.dart';
import 'package:flutter/services.dart';
import 'package:frog_app_utils_plugin/environment/frog_environment_plugin.dart';
import 'package:frog_app_utils_plugin/frog_app.dart';
import 'package:frog_log_plugin/log_utils.dart';
import 'package:http/http.dart' as http;

import 'package:common_module/common_module_constant.dart';
import 'model.dart';

abstract class IStaticUrlConfigService {
  String getShareUrl();

  Future<StaticUrlConfig> getCacheStaticUrlConfig();
}

class StaticUrlConfigManager implements IStaticUrlConfigService {
  ///链接配置文件
  static const String FILE_THEME = "static_url_config.json";

  static String normalScheme = CommonModuleConstant.HTML_HOST;

  ///
  static Future<String> getFinalLinkPrefix() async {
    return normalScheme + (await FrogEnvironmentPlugin().getOssParentFolder() ?? '') + "/yesdesk";
  }

  ///
  static Future<String> getJsonLink() async {
    return await getFinalLinkPrefix() + "/commonality/assets/json/enter.json";
  }

  //当前配置
  StaticUrlConfig _config;

  StaticUrlConfig get config => _config;

  static final StaticUrlConfigManager _instance = StaticUrlConfigManager._internal();

  factory StaticUrlConfigManager() {
    return _instance;
  }

  StaticUrlConfigManager._internal() {
    initListen();
  }

  void initListen() {
    initStaticUrlConfig();
  }

  void initStaticUrlConfig() async {
    var netConfig; //= await getNetStaticUrlConfig();
    // /// for test
    // var netConfig;
    if (netConfig == null) {
      //网络状态没数据 => 本地配置
      // 初始化
      getCacheStaticUrlConfig();
      L.debug(tag: "common_module/static_url", message: "当前使用本地动态配置");
    } else {
      L.debug(tag: "common_module/static_url", message: "当前使用网络动态配置");
    }
  }

  String getShareUrl() {
    // String shareUrl;
    // if (FrogApp.isDebug) {
    //   shareUrl = 'https://beta.xiaohuxi.cn/yesshare';
    // } else {
    //   shareUrl = 'https://y.yes321.com/yesshare';
    // }
    return GlobalConfig.instance.staticShareUrl;
  }

  Future<StaticUrlConfig> getCacheStaticUrlConfig() async {
    StaticUrlConfig currentConfig;
    if (currentConfig == null) {
      String jsonStr = await rootBundle.loadString(CommonModuleConstant.getAssetsJsonKey('lib/service/static_url_service/$FILE_THEME'));
      Map<String, dynamic> obj = json.decode(jsonStr);
      currentConfig = StaticUrlConfig.fromJson(obj, true);
      _config = currentConfig;
    }

    return currentConfig;
  }

  Future<StaticUrlConfig> getNetStaticUrlConfig() async {
    try {
      StaticUrlConfig currentConfig;
      var client = http.Client();

      var uri = Uri.parse(await getJsonLink());

      http.Response response = await client.get(uri);

      if (response.statusCode == 200 || response.body != null) {
        print("动态链接配置请求成功:${response.body}");
        Map<String, dynamic> obj = json.decode(response.body);
        currentConfig = StaticUrlConfig.fromJson(obj, false);
        _config = currentConfig;
        return currentConfig;
      } else {
        print('动态链接配置请求失败 code 码为${response.statusCode}');
        return null;
      }
    } catch (e) {
      L.error(tag: "StaticUrlConfigManager", message: "getNetStaticUrlConfig() error:$e");
    }
  }
}
